Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(346)

Unified Diff: third_party/WebKit/Source/core/html/HTMLFormElement.h

Issue 2546063002: Rename FormAssociatedElement to ListedElement (Closed)
Patch Set: Suggested changes made Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/html/HTMLFormElement.h
diff --git a/third_party/WebKit/Source/core/html/HTMLFormElement.h b/third_party/WebKit/Source/core/html/HTMLFormElement.h
index f0daf4bb074a090fa8760ff14250b3833e5111d2..980398ec2eaff2e0581132357ae116399908b3bb 100644
--- a/third_party/WebKit/Source/core/html/HTMLFormElement.h
+++ b/third_party/WebKit/Source/core/html/HTMLFormElement.h
@@ -34,7 +34,7 @@
namespace blink {
class Event;
-class FormAssociatedElement;
+class ListedElement;
class HTMLFormControlElement;
class HTMLFormControlsCollection;
class HTMLImageElement;
@@ -62,8 +62,8 @@ class CORE_EXPORT HTMLFormElement final : public HTMLElement {
bool shouldAutocomplete() const;
- void associate(FormAssociatedElement&);
- void disassociate(FormAssociatedElement&);
+ void associate(ListedElement&);
+ void disassociate(ListedElement&);
void associate(HTMLImageElement&);
void disassociate(HTMLImageElement&);
void didAssociateByParser();
@@ -98,7 +98,7 @@ class CORE_EXPORT HTMLFormElement final : public HTMLElement {
return m_radioButtonGroupScope;
}
- const FormAssociatedElement::List& associatedElements() const;
+ const ListedElement::List& listedElements() const;
const HeapVector<Member<HTMLImageElement>>& imageElements();
void anonymousNamedGetter(const AtomicString& name, RadioNodeListOrElement&);
@@ -129,8 +129,7 @@ class CORE_EXPORT HTMLFormElement final : public HTMLElement {
void scheduleFormSubmission(FormSubmission*);
- void collectAssociatedElements(Node& root,
- FormAssociatedElement::List&) const;
+ void collectListedElements(Node& root, ListedElement::List&) const;
void collectImageElements(Node& root, HeapVector<Member<HTMLImageElement>>&);
// Returns true if the submission should proceed.
@@ -154,9 +153,9 @@ class CORE_EXPORT HTMLFormElement final : public HTMLElement {
RadioButtonGroupScope m_radioButtonGroupScope;
// Do not access m_associatedElements directly. Use associatedElements()
// instead.
- FormAssociatedElement::List m_associatedElements;
+ ListedElement::List m_listedElements;
// Do not access m_imageElements directly. Use imageElements() instead.
HeapVector<Member<HTMLImageElement>> m_imageElements;
@@ -168,7 +167,7 @@ class CORE_EXPORT HTMLFormElement final : public HTMLElement {
bool m_isSubmitting = false;
bool m_inUserJSSubmitEvent = false;
- bool m_associatedElementsAreDirty : 1;
+ bool m_listedElementsAreDirty : 1;
bool m_imageElementsAreDirty : 1;
bool m_hasElementsAssociatedByParser : 1;
bool m_hasElementsAssociatedByFormAttribute : 1;
@@ -154,9 +153,9 @@ class CORE_EXPORT HTMLFormElement final : public HTMLElement {
RadioButtonGroupScope m_radioButtonGroupScope;
- // Do not access m_associatedElements directly. Use associatedElements()
+ // Do not access m_listedElements directly. Use listedElements()
// instead.

Powered by Google App Engine
This is Rietveld 408576698